@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '1.04'; # VERSION
+our $DATE = '2015-04-07'; # DATE
+our $VERSION = '1.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -95,6 +95,7 @@ our %copts = (
 
     version => {
         getopt  => "version|v",
+        summary => "Display program's version and exit",
         usage   => "--version (or -v)",
         handler => sub {
             my ($go, $val, $r) = @_;
@@ -105,7 +106,7 @@ our %copts = (
 
     help => {
         getopt  => 'help|h|?',
-        summary => 'Display this help message',
+        summary => 'Display help message and exit',
         usage   => "--help (or -h, -?)",
         handler => sub {
             my ($go, $val, $r) = @_;
@@ -123,6 +124,8 @@ our %copts = (
             $r->{format} = $val;
         },
         default => undef,
+        tags => ['category:output'],
+        is_settable_via_config => 1,
     },
     json => {
         getopt  => 'json',
@@ -131,6 +134,7 @@ our %copts = (
             my ($go, $val, $r) = @_;
             $r->{format} = 'json';
         },
+        tags => ['category:output'],
     },
 
     naked_res => {
@@ -157,6 +161,8 @@ _
             $r->{naked_res} = $val ? 1:0;
         },
         default => 0,
+        tags => ['category:output'],
+        is_settable_via_config => 1,
     },
 
     subcommands => {
@@ -206,6 +212,7 @@ _
             $r->{config_paths} //= [];
             push @{ $r->{config_paths} }, $val;
         },
+        tags => ['category:configuration'],
     },
     no_config => {
         getopt  => 'no-config',
@@ -214,6 +221,7 @@ _
             my ($go, $val, $r) = @_;
             $r->{read_config} = 0;
         },
+        tags => ['category:configuration'],
     },
     config_profile => {
         getopt  => 'config-profile=s',
@@ -262,6 +270,7 @@ _
             Complete::Util::complete_array_elem(
                 array=>[sort @profiles], word=>$word, ci=>1);
         },
+        tags => ['category:configuration'],
     },
 
     # since the cmdline opts is consumed, Log::Any::App doesn't see this. we
@@ -276,6 +285,8 @@ _
             $r->{log_level} = $val;
             $ENV{LOG_LEVEL} = $val;
         },
+        is_settable_via_config => 1,
+        tags => ['category:logging'],
     },
     trace => {
         getopt  => "trace",
@@ -284,6 +295,7 @@ _
             my ($go, $val, $r) = @_;
             $ENV{TRACE} = 1;
         },
+        tags => ['category:logging'],
     },
     debug => {
         getopt  => "debug",
@@ -292,6 +304,7 @@ _
             my ($go, $val, $r) = @_;
             $ENV{DEBUG} = 1;
         },
+        tags => ['category:logging'],
     },
     verbose => {
         getopt  => "verbose",
@@ -301,6 +314,7 @@ _
             $ENV{VERBOSE} = 1;
             $r->{_help_verbose} = 1;
         },
+        tags => ['category:logging'],
     },
     quiet => {
         getopt  => "quiet",
@@ -309,6 +323,7 @@ _
             my ($go, $val, $r) = @_;
             $ENV{QUIET} = 1;
         },
+        tags => ['category:logging'],
     },
 
 );
@@ -687,10 +702,12 @@ sub _parse_argv2 {
             $self->hook_after_read_config_file($r);
 
             my $res = Perinci::CmdLine::Util::Config::get_args_from_config(
+                r                  => $r,
                 config             => $r->{config},
                 args               => \%args,
                 subcommand_name    => $r->{subcommand_name},
                 config_profile     => $r->{config_profile},
+                common_opts        => $self->common_opts,
                 meta               => $meta,
                 meta_is_normalized => 1,
             );
@@ -1214,7 +1231,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.04 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-02.
+This document describes version 1.05 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-07.
 
 =head1 DESCRIPTION
 
@@ -1470,7 +1487,8 @@ Set to true if user specifies C<--naked-res>.
 
 =head1 CONFIGURATION
 
-Configuration can be used to set function arguments.
+Configuration can be used to set function arguments as well as some common
+options.
 
 Configuration is currently in the L<IOD> (basically INI) format.
 
@@ -1478,10 +1496,11 @@ By default these paths are searched: C<$HOME/.config/$prog_name.conf>,
 C<$HOME/$prog_name.conf>, C</etc/$prog_name.conf>. The location can be
 customized from command-line option C<--config-path>.
 
-All existing configuration files will be read in order.
+All existing configuration files will be read in order, and the result merged if
+more than one files exist.
 
-For application that does not have subcommand, you can put parameters outside
-any section, e.g.:
+Section names map to subcommand names. For application that does not have
+subcommand, you can put parameters outside any section, e.g.:
 
  param=val
  otherparam=val
@@ -1512,7 +1531,14 @@ all subcommands:
  ...
 
 A configuration file can also have (multiple) profiles, to allow multiple
-configuration to be stored in a single file. Example:
+configuration to be stored in a single file. Section names can have
+"profile=PROFILENAME" suffix to mark it as belonging to a certain profile.
+Parameters in sections with matching "profile=PROFILENAME" will be read.
+Parameters in sections without any profile names will still be read. Example:
+
+ a=0
+ b=0
+ d=9
 
  [profile=p1]
  a=1
@@ -1530,13 +1556,25 @@ configuration to be stored in a single file. Example:
 
 If you run:
 
+ % cmd subcommand1
+
+then your subcommand1 function will get: a=0, b=0, d=9.
+
  % cmd subcommand1 --config-profile p1
 
-then your subcommand1 function will get: a=1, b=2, c=3. If you run:
+then your subcommand1 function will get: a=1, b=2, c=3, d=9. If you run:
 
  % cmd subcommand1 --config-profile p2
 
-then your subcommand1 function will get: a=10, b=20, c=30.
+then your subcommand1 function will get: a=10, b=20, c=30, d=9.
+
+Parameter names map to function argument names or common option. If a common
+option name clashes with a function argument name, the function argument is
+accessible using the C<NAME.arg> syntax. For example, C<log_level> is a common
+option name. If your function also has a C<log_level> argument, to set this
+function argument, you write:
+
+ log_level.arg=blah
 
 =head1 ATTRIBUTES
 
